@@ -55,11 +55,11 @@ dnn_linear_combined_regressor <- function(model_dir = NULL,
       linear_optimizer = linear_optimizer,
       dnn_feature_columns = ensure_nullable_list(dnn_feature_columns),
       dnn_optimizer = dnn_optimizer,
-      dnn_hidden_units = lapply(dnn_hidden_units, ensure_scalar_integer),
+      dnn_hidden_units = cast_integer_list(dnn_hidden_units),
       dnn_activation_fn = resolve_activation_fn(dnn_activation_fn),
-      dnn_dropout = ensure_scalar_double(dnn_dropout, allow.null = TRUE),
-      label_dimension = ensure_scalar_integer(label_dimension),
-      weight_column = ensure_scalar_character(weight_column, allow.null = TRUE),
+      dnn_dropout = cast_nullable_scalar_double(dnn_dropout),
+      label_dimension = cast_scalar_integer(label_dimension),
+      weight_column = cast_nullable_string(weight_column),
       input_layer_partitioner = input_layer_partitioner,
       config = config
     )
@@ -95,11 +95,11 @@ dnn_linear_combined_classifier <- function(model_dir = NULL,
       linear_optimizer = linear_optimizer,
       dnn_feature_columns = ensure_nullable_list(dnn_feature_columns),
       dnn_optimizer = dnn_optimizer,
-      dnn_hidden_units = lapply(dnn_hidden_units, ensure_scalar_integer),
+      dnn_hidden_units = cast_integer_list(dnn_hidden_units),
       dnn_activation_fn = resolve_activation_fn(dnn_activation_fn),
-      dnn_dropout = ensure_scalar_double(dnn_dropout, allow.null = TRUE),
-      n_classes = ensure_scalar_integer(n_classes),
-      weight_column = ensure_scalar_character(weight_column, allow.null = TRUE),
+      dnn_dropout = cast_nullable_scalar_double(dnn_dropout),
+      n_classes = cast_scalar_integer(n_classes),
+      weight_column = cast_nullable_string(weight_column),
       label_vocabulary = label_vocabulary,
       input_layer_partitioner = input_layer_partitioner,
       config = config
